@@ -1,6 +1,3 @@
 """DoHome Lights controlling module"""
-import sys
-sys.path.append(".")
-
 from dohome_api.gateway import DoHomeGateway
 from dohome_api.light import DoHomeLight
